import argparse, JsonParser, traceback
import Settings.Environment as Environment
import Settings.Configuration as Configuration
from EventHub.Response import Response
from EventHub.EventHubProducer import EventHubProducer

def run():
    events_json = JsonParser.parse(args.events)
    event_type = args.type
    client_code = args.code
    account_name = args.account
    env_name = args.env
    return send_events(event_type, env_name, client_code, account_name, events_json)

def send_events(event_type, env_name, client_code, account_name, events):
    try:
        Environment.set_environment(env_name)  
        producer = EventHubProducer(Configuration.get_connection_string(), Configuration.get_eventhub_name())
        producer.send_batch_with_partition_key(event_type, event_type, client_code, account_name, events)
        return Response(True, "").toJSON()
    except Exception as eh_err:
        return Response(False, traceback.format_exc()).toJSON()  

#Declare script parameters
parser = argparse.ArgumentParser()
parser.add_argument("--env", help="Sets environment. Development, Production, QA or Learn", type=str)
parser.add_argument("--code", help="Sets Storis client code", type=str)
parser.add_argument("--events", help="Sets Storis client code")
parser.add_argument("--account", help="Sets Storis Account name")
parser.add_argument("--type", help="Sets Storis Event type")

args, unknown = parser.parse_known_args()


    




class Settings(object):
    def __init__(self, connectionString, name):
        self.connectionString = connectionString
        self.name = name

    def object_decoder(obj):
        if '__type__' in obj and obj['__type__'] == 'Settings':
            return Settings(obj['connectionString'], obj['name'])
        return obj



import sys, os
from pathlib import Path

currentDirectory = os.getcwd()
#eventHubDirectory = currentDirectory + "\EventPublisher\EventHub"
#settingsDirectory = currentDirectory + "\EventPublisher\Settings"
eventPublisherDirectory = currentDirectory + "\EventPublisher"
#path = Path(currentDirectory) 
#absolutePath = str(path.parent.absolute())
sys.path.append(eventPublisherDirectory)
#sys.path.append(currentDirectory)
#sys.path.append(eventHubDirectory)
#sys.path.append(settingsDirectory)
#sys.path.append(absolutePath)

# change the current directory so we can read the settings.json
os.chdir(eventPublisherDirectory)

import EventHub.SendEvents as SendEvents
import EventPublisher.Publisher as Publisher

json = '{"environment":"Development", "eventType":"OrderWrittenSale", "clientCode":"fla-105-code", "accountName":"fla-105", "data":[{"entityId":"a"}]}'

respose = Publisher.run(json)
print(respose)


import os, JsonParser

def get_environment():
    env = os.getenv('APP_ENVIRONMENT')
    if env == None:
        raise Exception("Environment is not set. Set Production or Development by calling 'python Environment.py <env_name>'")
    return env

def get_environment_settings():
    settingsJson = os.getenv('APP_ENVIRONMENT_SETTINGS')
    if settingsJson == None:
        raise Exception("Environment settings are not set")
    env = get_environment()
    settings = JsonParser.parse(settingsJson)
    return JsonParser.get_by_key(settings, env)

def read_settings():
    settings = JsonParser.parse_from_file('../settings.json')
    set_environment_settings(settings)

def set_environment_settings(settings):
    os.environ['APP_ENVIRONMENT_SETTINGS'] = JsonParser.serialize(settings)

def set_environment(envirment_name):
    os.environ['APP_ENVIRONMENT'] = envirment_name
    read_settings()




ORDER_DELETED = "OrderDeleted"
ORDER_WRITTEN_SALE = "OrderWrittenSale"
FULFILMENT_SCHEDULED_DELIVERY = "FulfillmentScheduledDelivery"
FULFILMENT_FULLY_RESERVED = "FulfillmentFullyReserved"
FULFILMENT_COPLETED = "FulfillmentCompleted"

EVENTS = [
    ORDER_DELETED,
    ORDER_WRITTEN_SALE,
    FULFILMENT_SCHEDULED_DELIVERY,
    FULFILMENT_FULLY_RESERVED,
    FULFILMENT_COPLETED,    
    ]



import Settings.Environment

def get():
    return Settings.Environment.get_environment_settings()

def get_connection_string():
    settings = get()
    return settings["ConnectionString"]

def get_eventhub_name():
    settings = get()
    return settings["Name"]



import json

def parse(json_string):
    return  json.loads(json_string)

def get_by_key(data, key):
    if key in data:
        return data[key]
    else:
        raise Exception(key + " does not exists.")

def parse_from_file(path):
    jsonFile = open('../settings.json', "r")
    return json.loads(jsonFile.read())

def serialize(obj):
    return json.dumps(obj)